==> zio-aws-pinpoint_3-5.17.104.12-sources.jar: zio/aws/pinpoint/model/GetGcmChannelRequest.scala <==
package zio.aws.pinpoint.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import zio.aws.pinpoint.model.primitives.__string
import scala.jdk.CollectionConverters.*
final case class GetGcmChannelRequest(applicationId: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.pinpoint.model.GetGcmChannelRequest = {
    import GetGcmChannelRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.pinpoint.model.GetGcmChannelRequest
      .builder()
      .applicationId(__string.unwrap(applicationId): java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.pinpoint.model.GetGcmChannelRequest.ReadOnly =
    zio.aws.pinpoint.model.GetGcmChannelRequest.wrap(buildAwsValue())
}
object GetGcmChannelRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.pinpoint.model.GetGcmChannelRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.pinpoint.model.GetGcmChannelRequest =
      zio.aws.pinpoint.model.GetGcmChannelRequest(applicationId)
    def applicationId: __string
    def getApplicationId: ZIO[Any, Nothing, __string] =
      ZIO.succeed(applicationId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.pinpoint.model.GetGcmChannelRequest
  ) extends zio.aws.pinpoint.model.GetGcmChannelRequest.ReadOnly {
    override val applicationId: __string =
      zio.aws.pinpoint.model.primitives.__string(impl.applicationId())
  }
  def wrap(
      impl: software.amazon.awssdk.services.pinpoint.model.GetGcmChannelRequest
  ): zio.aws.pinpoint.model.GetGcmChannelRequest.ReadOnly = new Wrapper(impl)
}

==> zio-aws-pinpoint_3-6.20.78.3-sources.jar: zio/aws/pinpoint/model/GetGcmChannelRequest.scala <==
package zio.aws.pinpoint.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import zio.aws.pinpoint.model.primitives.__string
import scala.jdk.CollectionConverters.*
final case class GetGcmChannelRequest(applicationId: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.pinpoint.model.GetGcmChannelRequest = {
    import GetGcmChannelRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.pinpoint.model.GetGcmChannelRequest
      .builder()
      .applicationId(applicationId: java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.pinpoint.model.GetGcmChannelRequest.ReadOnly =
    zio.aws.pinpoint.model.GetGcmChannelRequest.wrap(buildAwsValue())
}
object GetGcmChannelRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.pinpoint.model.GetGcmChannelRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.pinpoint.model.GetGcmChannelRequest =
      zio.aws.pinpoint.model.GetGcmChannelRequest(applicationId)
    def applicationId: __string
    def getApplicationId: ZIO[Any, Nothing, __string] =
      ZIO.succeed(applicationId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.pinpoint.model.GetGcmChannelRequest
  ) extends zio.aws.pinpoint.model.GetGcmChannelRequest.ReadOnly {
    override val applicationId: __string = impl.applicationId(): __string
  }
  def wrap(
      impl: software.amazon.awssdk.services.pinpoint.model.GetGcmChannelRequest
  ): zio.aws.pinpoint.model.GetGcmChannelRequest.ReadOnly = new Wrapper(impl)
}
